import _extends from '@babel/runtime/helpers/esm/extends';
import React from 'react';
import { Spring, animated } from 'react-spring';

var STYLE_WRAPPER = {
  alignItems: 'center',
  boxSizing: 'border-box',
  display: 'flex',
  justifyContent: 'center',
  position: 'relative'
};
var STYLE_SVG = {
  bottom: 0,
  left: 0,
  position: 'absolute',
  right: 0,
  top: 0,
  transform: 'rotate(-90deg)'
};

var ProgressCircle = function ProgressCircle(_ref) {
  var bgColor = _ref.bgColor,
      children = _ref.children,
      progress = _ref.progress,
      progressColor = _ref.progressColor,
      size = _ref.size,
      strokeWidth = _ref.strokeWidth;
  var circleSize = size / 2;
  var circleRadius = circleSize - strokeWidth / 2;
  var circleDash = 2 * Math.PI * circleRadius;
  var circleProps = {
    fill: 'none',
    cx: circleSize,
    cy: circleSize,
    r: circleRadius,
    strokeWidth: strokeWidth
  };
  return React.createElement("div", {
    style: _extends({}, STYLE_WRAPPER, {
      height: size,
      width: size
    })
  }, typeof children === 'function' ? React.createElement(Spring, {
    to: {
      progress: progress
    }
  }, children) : children, React.createElement(Spring, {
    native: true,
    to: {
      offset: circleDash * (1 - progress / 100)
    }
  }, function (_ref2) {
    var offset = _ref2.offset;
    return React.createElement("svg", {
      width: size,
      height: size,
      viewBox: "0 0 " + size + " " + size,
      style: STYLE_SVG
    }, React.createElement("circle", _extends({}, circleProps, {
      stroke: bgColor
    })), React.createElement(animated.circle, _extends({}, circleProps, {
      stroke: progressColor,
      strokeDasharray: circleDash,
      strokeDashoffset: offset.interpolate(function (v) {
        return v;
      })
    })));
  }));
};

ProgressCircle.defaultProps = {
  bgColor: 'rgba(165, 180, 186, 0.4)',
  progress: 0,
  progressColor: '#a5b4ba',
  size: 40,
  strokeWidth: 2
};

export default ProgressCircle;
